#[non_exhaustive]pub enum FlowSelectionError {
UnknownNode {
node: NodeId,
},
UnmappedExitOutcome {
node: NodeId,
code: ExitCode,
},
}Expand description
A compiled plan that cannot route one observed exit outcome.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownNode
The requested node is not part of this plan.
UnmappedExitOutcome
No declared pattern matches the produced exit outcome.