#[non_exhaustive]pub enum LocalFailurePolicy {
CancelSiblings,
DrainSiblings,
}Expand description
The sibling behavior selected after one local child fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CancelSiblings
Request cooperative cancellation of siblings, then join all children.
DrainSiblings
Allow siblings to reach their next boundary, then join all children.